# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['profanity_check']

package_data = \
{'': ['*'], 'profanity_check': ['data/*']}

setup_kwargs = {
    'name': 'profanity-check2',
    'version': '0.1.1',
    'description': 'Profanity Check2: Drop-in Replacement for profanity-check',
    'long_description': '# profanity-check\n\n[![Build Status](https://travis-ci.com/vzhou842/profanity-check.svg?branch=master)](https://travis-ci.com/vzhou842/profanity-check)\n[![release](https://img.shields.io/badge/dynamic/json.svg?label=release&url=https%3A%2F%2Fpypi.org%2Fpypi%2Fprofanity-check%2Fjson&query=%24.info.version&colorB=blue)](https://pypi.org/project/profanity-check/)\n\nA fast, robust Python library to check for profanity or offensive language in strings. Read more about how and why `profanity-check` was built in [this blog post](https://victorzhou.com/blog/better-profanity-detection-with-scikit-learn/). You can also test out `profanity-check` [in your browser](https://repl.it/@vzhou842/profanity-check-playground).\n\n## How It Works\n\n`profanity-check` uses a linear SVM model trained on 200k human-labeled samples of clean and profane text strings. Its model is simple but surprisingly effective, meaning **`profanity-check` is both robust and extremely performant**.\n\n## Why Use profanity-check?\n\n### No Explicit Blacklist\n\nMany profanity detection libraries use a hard-coded list of bad words to detect and filter profanity. For example, [profanity](https://pypi.org/project/profanity/) uses [this wordlist](https://github.com/ben174/profanity/blob/master/profanity/data/wordlist.txt), and even [better-profanity](https://pypi.org/project/better-profanity/) still uses [a wordlist](https://github.com/snguyenthanh/better_profanity/blob/master/better_profanity/profanity_wordlist.txt). There are obviously glaring issues with this approach, and, while they might be performant, **these libraries are not accurate at all**.\n\nA simple example for which `profanity-check` is better is the phrase *"You cocksucker"* - `profanity` thinks this is clean because it doesn\'t have *"cocksucker"* in its wordlist.\n\n### Performance\n\nOther libraries like [profanity-filter](https://github.com/rominf/profanity-filter) use more sophisticated methods that are much more accurate but at the cost of performance. A benchmark (performed December 2018 on a new 2018 Macbook Pro) using [a Kaggle dataset of Wikipedia comments](https://www.kaggle.com/c/jigsaw-toxic-comment-classification-challenge/data) yielded roughly the following results:\n\n| Package | 1 Prediction (ms) | 10 Predictions (ms) | 100 Predictions (ms)\n| --------|-------------------|---------------------|-----------------------\n| profanity-check | 0.2 | 0.5 | 3.5\n| profanity-filter | 60 | 1200 | 13000\n| profanity | 0.3 | 1.2 | 24\n\n`profanity-check` is anywhere from **300 - 4000 times faster** than `profanity-filter` in this benchmark!\n\n### Accuracy\n\nThis table speaks for itself:\n\n| Package | Test Accuracy | Balanced Test Accuracy | Precision | Recall | F1 Score\n| ------- | ------------- | ---------------------- | --------- | ------ | --------\n| profanity-check | 95.0% | 93.0% | 86.1% | 89.6% | 0.88\n| profanity-filter | 91.8% | 83.6% | 85.4% | 70.2% | 0.77\n| profanity | 85.6% | 65.1% | 91.7% | 30.8% | 0.46\n\nSee the How section below for more details on the dataset used for these results.\n\n## Installation\n\n```\n$ pip install profanity-check\n```\n\n## Usage\n\n```python\nfrom profanity_check import predict, predict_prob\n\npredict([\'predict() takes an array and returns a 1 for each string if it is offensive, else 0.\'])\n# [0]\n\npredict([\'fuck you\'])\n# [1]\n\npredict_prob([\'predict_prob() takes an array and returns the probability each string is offensive\'])\n# [0.08686173]\n\npredict_prob([\'go to hell, you scum\'])\n# [0.7618861]\n```\n\nNote that both `predict()` and `predict_prob` return [`numpy`](https://pypi.org/project/numpy/) arrays.\n\n## More on How/Why It Works\n\n### How\n\nSpecial thanks to the authors of the datasets used in this project. `profanity-check` was trained on a combined dataset from 2 sources:\n- [t-davidson/hate-speech-and-offensive-language](https://github.com/t-davidson/hate-speech-and-offensive-language/tree/master/data), used in their paper *Automated Hate Speech Detection and the Problem of Offensive Language*\n- the [Toxic Comment Classification Challenge](https://www.kaggle.com/c/jigsaw-toxic-comment-classification-challenge/data) on Kaggle.\n\n`profanity-check` relies heavily on the excellent [`scikit-learn`](https://scikit-learn.org/) library. It\'s mostly powered by `scikit-learn` classes [`CountVectorizer`](https://scikit-learn.org/stable/modules/generated/sklearn.feature_extraction.text.CountVectorizer.html), [`LinearSVC`](https://scikit-learn.org/stable/modules/generated/sklearn.svm.LinearSVC.html), and [`CalibratedClassifierCV`](https://scikit-learn.org/stable/modules/generated/sklearn.calibration.CalibratedClassifierCV.html). It uses a [Bag-of-words model](https://en.wikipedia.org/wiki/Bag-of-words_model) to vectorize input strings before feeding them to a linear classifier.\n\n### Why\n\nOne simplified way you could think about why `profanity-check` works is this: during the training process, the model learns which words are "bad" and how "bad" they are because those words will appear more often in offensive texts. Thus, it\'s as if the training process is picking out the "bad" words out of all possible words and using those to make future predictions. This is better than just relying on arbitrary word blacklists chosen by humans!\n\n## Caveats\n\nThis library is far from perfect. For example, it has a hard time picking up on less common variants of swear words like *"f4ck you"* or *"you b1tch"* because they don\'t appear often enough in the training corpus. **Never treat any prediction from this library as unquestionable truth, because it does and will make mistakes.** Instead, use this library as a heuristic.\n',
    'author': 'John James',
    'author_email': 'john@variancexplained.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://variancexplained.github.io/profanity-check2',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.7.1,<4.0',
}


setup(**setup_kwargs)
